@@ -1,6 +1,6 @@
 /************************************************************************
  **
- **  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford Ontario Canada
+ **  Copyright (C) 2019-2024 Kevin B. Hendricks, Stratford Ontario Canada
  **
  **  This file is part of PageEdit.
  **
@@ -86,9 +86,7 @@ Inspector::~Inspector()
     if (m_inspectView) {
         m_inspectView->close();
         m_view = nullptr;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
         m_inspectView->page()->setInspectedPage(nullptr);
-#endif
         delete m_inspectView;
         m_inspectView = nullptr;
     }
@@ -148,31 +146,16 @@ void Inspector::UpdateFinishedState(bool okay)
 void Inspector::InspectPageofView(QWebEngineView* view)
 {
     m_view = view;
-
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     if (m_view) {
         m_inspectView->page()->setInspectedPage(m_view->page());
     } 
-#else
-    if (m_view) {
-        QString not_supported = tr("The Inspector functionality is not supported before Qt 5.11");
-	QString response = "<html><head><title>Warning</title></head><body><p>" + 
-	                   not_supported + "</p></body></html>";
-        m_inspectView->setHtml(response);
-	show();
-    }
-#endif
 }
 
 void Inspector::StopInspection()
 {
     SaveSettings();
     m_view = nullptr;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     m_inspectView->page()->setInspectedPage(nullptr);
-#else
-    m_inspectView->setHtml("<html><head><title></title></head><body></body></html>");
-#endif
 }
 
 
