@@ -1,24 +1,25 @@
 /************************************************************************
 **
-**  Copyright (C) 2019 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2019-2024 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2019-2024 Doug Massay
 **  Copyright (C) 2012 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012 Grant Drake
 **  Copyright (C) 2012 Dave Heiland
 **
-**  This file is part of Sigil.
+**  This file is part of PageEdit.
 **
-**  Sigil is free software: you can redistribute it and/or modify
+**  PageEdit is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
-**  Sigil is distributed in the hope that it will be useful,
+**  PageEdit is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
-**  along with Sigil.  If not, see <http://www.gnu.org/licenses/>.
+**  along with PageEdit.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/
 
@@ -30,7 +31,7 @@
 #include <QPalette>
 #include <QApplication>
 
-class QStyle;
+class QTimer;
 
 class MainApplication : public QApplication
 {
@@ -40,7 +41,7 @@ public:
     MainApplication(int &argc, char **argv);
 
     bool isDarkMode() { return m_isDark; }
-    void fixMacDarkModePalette(QPalette & pal);
+    bool AlwaysUseNFC(){ return m_AlwaysUseNFC; };
 
 signals:
     void applicationActivated();
@@ -49,13 +50,17 @@ signals:
 
 public slots:
     void EmitPaletteChanged();
+    void systemColorChanged();
 
 protected:
     bool event(QEvent *pEvent);
 
 private:
-    QStyle * m_Style;
+    void windowsDarkThemeChange();
+    void windowsLightThemeChange();
     bool m_isDark;
+    QTimer * m_PaletteChangeTimer;
+    bool m_AlwaysUseNFC = true;
 };
 
 #endif // MAINAPPLICATION_H
