@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2023 Kevin Hendricks, Doug Massay
+**  Copyright (C) 2019-2024 Kevin Hendricks, Doug Massay
 **
 **  This file is part of PageEdit.
 **
@@ -471,11 +471,6 @@ float MainWindow::SliderRangeToZoomFactor(int slider_range_value)
 
 void MainWindow::resizeEvent(QResizeEvent *event)
 {
-    // Workaround for Qt 4.8 bug - see WriteSettings() for details.                                             
-    if (!isMaximized()) {
-        m_LastWindowSize = saveGeometry();
-    }
-    // Update self normally
     QMainWindow::resizeEvent(event);
     UpdateWindowTitle();
 }
@@ -1175,10 +1170,6 @@ void MainWindow::closeEvent(QCloseEvent *event)
 
 void MainWindow::moveEvent(QMoveEvent *event)
 {
-    // Workaround for Qt 4.8 bug - see WriteSettings() for details.                                             
-    if (!isMaximized()) {
-        m_LastWindowSize = saveGeometry();
-    }
     QMainWindow::moveEvent(event);
 }
 
@@ -1188,18 +1179,14 @@ void MainWindow::LoadSettings()
     m_skipPrintWarnings = settings.skipPrintWarnings();
     m_skipPrintPreview = settings.skipPrintPreview();
     settings.beginGroup(SETTINGS_GROUP);
-    // The size of the window and its full screen status
-    // Due to the 4.8 bug, we restore its "normal" window size and then maximize
-    // it afterwards (if last state was maximized) to ensure on correct screen.
+    // no longer needed but keep in settings in case Qt bug returns
     bool isMaximized = settings.value("maximized", false).toBool();
+    bool isFullScreen = settings.value("maximized", false).toBool();
+
     m_LastWindowSize = settings.value("geometry").toByteArray();
 
     if (!m_LastWindowSize.isNull()) {
         restoreGeometry(m_LastWindowSize);
-
-        if (isMaximized) {
-            setWindowState(windowState() | Qt::WindowMaximized);
-        }
     }
 
     // The positions of all the toolbars and dock widgets
@@ -1208,6 +1195,7 @@ void MainWindow::LoadSettings()
     if (!toolbars.isNull()) {
         restoreState(toolbars);
     }
+
     m_Inspector->hide();
 
     m_preserveHeadingAttributes = settings.value("preserveheadingattributes", true).toBool();
@@ -1242,12 +1230,10 @@ void MainWindow::SaveSettings()
     settings.setSkipPrintWarnings(m_skipPrintWarnings);
     settings.setSkipPrintPreview(m_skipPrintPreview);
     settings.beginGroup(SETTINGS_GROUP);
-    // The size of the window and it's full screen status                                                       
-    // This is a workaround for this bug:                                                                       
-    // Maximizing PageEdit and then closing will forget the previous window size                                   
-    // and open it maximized on the wrong screen.                                                               
-    // https://bugreports.qt-project.org/browse/QTBUG-21371                                                     
+    // No longer needed but keep these in settings n case Qt bug returns
     settings.setValue("maximized", isMaximized());
+    settings.setValue("fullscreen", isFullScreen());
+
     settings.setValue("geometry", m_LastWindowSize);
     // The positions of all the toolbars and dock widgets                                                       
     settings.setValue("toolbars", saveState());
@@ -1599,7 +1585,6 @@ bool MainWindow::Save()
 
 void MainWindow::printRendered()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
     // Refresh skipflags from Prefs
     SettingsStore settings;
     m_skipPrintWarnings = settings.skipPrintWarnings();
@@ -1622,28 +1607,24 @@ void MainWindow::printRendered()
         msgbox.setDetailedText(detailed_text);
         msgbox.setStandardButtons(QMessageBox::Close);
         msgbox.setCheckBox(cb);
+#if QT_VERSION >= QT_VERSION_CHECK(6,7,0)
+        connect(cb, &QCheckBox::checkStateChanged, [this](Qt::CheckState state) {
+            if (state == Qt::CheckState::Checked) {
+                m_skipPrintWarnings = true;    
+            }
+        });
+#else
         connect(cb, &QCheckBox::stateChanged, [this](int state) {
             if (static_cast<Qt::CheckState>(state) == Qt::CheckState::Checked) {
                 m_skipPrintWarnings = true;    
             }
         });
+#endif
         msgbox.exec();
     }
     settings.setSkipPrintWarnings(m_skipPrintWarnings);
 
     m_WebViewPrinter->setPage(m_WebView->url(), m_skipPrintPreview);
-#else
-    QMessageBox msgbox;
-    QString text = tr("Feature not available before Qt5.12.x");
-    msgbox.setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
-    msgbox.setModal(true);
-    msgbox.setWindowTitle("PageEdit");
-    msgbox.setText("<h3>" + text + "</h3><br/>");
-    msgbox.setIcon(QMessageBox::Icon::Warning);
-    msgbox.setStandardButtons(QMessageBox::Close);
-    msgbox.exec();
-#endif
-
 }
 
 void MainWindow::Open()
@@ -1719,43 +1700,54 @@ void MainWindow::SelectAll() { m_WebView->triggerPageAction(QWebEnginePage::Sele
 void MainWindow::Paste()
 {
     QClipboard *clipboard = QApplication::clipboard();
-    const QMimeData * mimeData = clipboard->mimeData();
-    if (mimeData->hasHtml()) {
-        QMessageBox msgBox(QMessageBox::Question,
-               tr("Clipboard contains HTML formatting"),
-               tr("Do you want to paste clipboard data as plain text?"),
-               QMessageBox::Yes|QMessageBox::No|QMessageBox::Cancel);
-        msgBox.setDefaultButton(QMessageBox::Yes);
+    const QMimeData * md = clipboard->mimeData();
+    QString html;
+    if (md->hasText() || md->hasHtml()) {
+        // ownership will be passed to the clipboard
+        QMimeData * nmd = new QMimeData();
+        if (md->hasText()) {
+            QString txt = md->text();
+            txt = Utility::UseNFC(txt);
+            nmd->setText(txt);
+        }
+        if (md->hasHtml()) {
+            QString ht = md->html();
+            ht = Utility::UseNFC(ht);
 
-        // populate the detailed text window - by HTML not by the text
-        msgBox.setDetailedText(mimeData->html());
+#if defined(Q_OS_WIN32)
+            // work around QtWebEngine Window's bug with clipboard html with no context
+            // by adding context back and creating a new clipboard element
+             if (ht.indexOf("<html") == -1) {
+                int pos = ht.indexOf("<");
+                if (pos == -1) pos = 0;
+                ht.insert(pos, "<html>\r\n<body>\r\n");
+                ht.append("\r\n</body>\r\n</html>");
+            }
+#endif
+            html = ht;
+            nmd->setHtml(ht);
+        }
+        clipboard->setMimeData(nmd);
+    }
+    if (!html.isEmpty()) {
+        QMessageBox msgBox(QMessageBox::Question,
+          tr("Clipboard contains HTML formatting"),
+          tr("Do you want to paste clipboard data as plain text?"),
+          QMessageBox::Yes|QMessageBox::No|QMessageBox::Cancel);
+        msgBox.setDefaultButton(QMessageBox::Yes);
+        // populate the detailed text window - by HTML
+        msgBox.setDetailedText(html);
         int rv = msgBox.exec();
         if (rv == QMessageBox::Yes) {
             m_WebView->triggerPageAction(QWebEnginePage::PasteAndMatchStyle);
         } else if (rv == QMessageBox::No) {
-#if defined(Q_OS_WIN32)
-            // work around QtWebEngine Window's bug with clipboard html with no context
-            // by adding context back and creating a new clipboard element
-            QString html = mimeData->html();
-            QString text;
-            if (mimeData->hasText()) text = mimeData->text();
-            if (html.indexOf("<html") == -1) {
-                int pos = html.indexOf("<");
-                if (pos == -1) pos = 0;
-                html.insert(pos, "<html>\r\n<body>\r\n");
-                html.append("\r\n</body>\r\n</html>");
-                QMimeData * newdata = new QMimeData();
-                newdata->setHtml(html);
-                if (!text.isEmpty()) newdata->setText(text);
-                // ownership is passed to clipboard
-                clipboard->setMimeData(newdata);
-            }
-#endif
             m_WebView->triggerPageAction(QWebEnginePage::Paste);
-        }  // else Cancel was clicked - do nothing
-    } else {
-        m_WebView->triggerPageAction(QWebEnginePage::Paste);
+        }
+        // all pasted or Cancel was used
+        return;
     }
+    // handle all other mimedata types
+    m_WebView->triggerPageAction(QWebEnginePage::Paste);
 }
 
 void MainWindow::PasteText(const QString& text)
@@ -1943,7 +1935,6 @@ void MainWindow::Superscript()
 }
 
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 void MainWindow::Bold()               { m_WebView->triggerPageAction(QWebEnginePage::ToggleBold);          }
 void MainWindow::Italic()             { m_WebView->triggerPageAction(QWebEnginePage::ToggleItalic);        }
 void MainWindow::Underline()          { m_WebView->triggerPageAction(QWebEnginePage::ToggleUnderline);     }
@@ -1956,20 +1947,6 @@ void MainWindow::DecreaseIndent()     { m_WebView->triggerPageAction(QWebEngineP
 void MainWindow::IncreaseIndent()     { m_WebView->triggerPageAction(QWebEnginePage::Indent);              }
 void MainWindow::InsertBulletedList() { m_WebView->triggerPageAction(QWebEnginePage::InsertUnorderedList); }
 void MainWindow::InsertNumberedList() { m_WebView->triggerPageAction(QWebEnginePage::InsertOrderedList);   }
-#else
-void MainWindow::Bold()               { m_WebView->ExecCommand("bold");                }
-void MainWindow::Italic()             { m_WebView->ExecCommand("italic");              }
-void MainWindow::Underline()          { m_WebView->ExecCommand("underline");           }
-void MainWindow::Strikethrough()      { m_WebView->ExecCommand("strikeThrough");       }
-void MainWindow::AlignLeft()          { m_WebView->ExecCommand("justifyLeft");         }
-void MainWindow::AlignCenter()        { m_WebView->ExecCommand("justifyCenter");       }
-void MainWindow::AlignRight()         { m_WebView->ExecCommand("justifyRight");        }
-void MainWindow::AlignJustify()       { m_WebView->ExecCommand("justifyFull");         }
-void MainWindow::DecreaseIndent()     { m_WebView->ExecCommand("outdent");             }
-void MainWindow::IncreaseIndent()     { m_WebView->ExecCommand("indent");              }
-void MainWindow::InsertBulletedList() { m_WebView->ExecCommand("insertUnorderedList"); }
-void MainWindow::InsertNumberedList() { m_WebView->ExecCommand("insertOrderedList");   }
-#endif
 
 void MainWindow::ShowMessageOnStatusBar(const QString &message,
                                         int millisecond_duration)
@@ -2140,11 +2117,7 @@ void MainWindow::ConnectSignalsToSlots()
     connect(ui.actionHeadingNormal, SIGNAL(triggered()), m_headingMapper, SLOT(map()));
     m_headingMapper->setMapping(ui.actionHeadingNormal, "Normal");
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(m_headingMapper, SIGNAL(mapped(const QString &)), this, SLOT(ApplyHeadingToSelection(const QString &)));
-#else
     connect(m_headingMapper, SIGNAL(mappedString(const QString &)), this, SLOT(ApplyHeadingToSelection(const QString &)));
-#endif
 
     connect(ui.actionHeadingPreserveAttributes,SIGNAL(triggered(bool)),this,SLOT(SetPreserveHeadingAttributes(bool)));
 
@@ -2207,11 +2180,7 @@ void MainWindow::ConnectSignalsToSlots()
     m_casingChangeMapper->setMapping(ui.actionCasingUppercase,  Utility::Casing_Uppercase);
     m_casingChangeMapper->setMapping(ui.actionCasingTitlecase, Utility::Casing_Titlecase);
     m_casingChangeMapper->setMapping(ui.actionCasingCapitalize, Utility::Casing_Capitalize);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(m_casingChangeMapper, SIGNAL(mapped(int)), this, SLOT(ChangeCasing(int)));
-#else
     connect(m_casingChangeMapper, SIGNAL(mappedInt(int)), this, SLOT(ChangeCasing(int)));
-#endif
 
     // View/Zoom Related
     connect(ui.actionZoomIn,     SIGNAL(triggered()),       this, SLOT(ZoomIn()));
