@@ -1,6 +1,6 @@
 /************************************************************************
  **
- **  Copyright (C) 2019-2021 Kevin B. Hendricks, Stratford Ontario Canada
+ **  Copyright (C) 2019-2024 Kevin B. Hendricks, Stratford Ontario Canada
  **
  **  This file is part of PageEdit.
  **
@@ -35,14 +35,12 @@
 #include <QtWebEngineCore>
 #include <QWebEngineScript>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QWebEngineFindTextResult>
-#endif
-
 
 #include "SearchToolbar.h"
 #include "WebViewEdit.h"
 #include "WebPageEdit.h"
+#include "Utility.h"
 #include "FocusSelectLineEdit.h"
 #include "ui_SearchToolbar.h"
 
@@ -78,6 +76,13 @@ SearchToolbar::SearchToolbar(WebViewEdit* view, QWidget* parent)
 
 }
 
+QString SearchToolbar::getNeedle()
+{
+    QString needle = ui->lineEdit->text();
+    needle = Utility::UseNFC(needle);
+    return needle;
+}
+
 void SearchToolbar::focusSearchLine()
 {
     ui->lineEdit->setFocus();
@@ -96,7 +101,7 @@ void SearchToolbar::findNext()
     m_findFlags = QWebEnginePage::FindFlags();
     updateFindFlags();
 
-    searchText(ui->lineEdit->text());
+    searchText(getNeedle());
 }
 
 void SearchToolbar::findPrevious()
@@ -104,7 +109,7 @@ void SearchToolbar::findPrevious()
     m_findFlags = QWebEnginePage::FindBackward;
     updateFindFlags();
 
-    searchText(ui->lineEdit->text());
+    searchText(getNeedle());
 }
 
 void SearchToolbar::updateFindFlags()
@@ -122,7 +127,7 @@ void SearchToolbar::caseSensitivityChanged()
     updateFindFlags();
 
     searchText(QString());
-    searchText(ui->lineEdit->text());
+    searchText(getNeedle());
 }
 
 void SearchToolbar::setText(const QString &text)
@@ -134,16 +139,12 @@ void SearchToolbar::setText(const QString &text)
 void SearchToolbar::searchText(const QString &text)
 {
     QPointer<SearchToolbar> guard = this;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    m_view->findText(text, m_findFlags, [=](bool found) {
-#else
     m_view->findText(text, m_findFlags, [=](const QWebEngineFindTextResult& result) {
     bool found = result.numberOfMatches() > 0;
-#endif
         if (!guard) {
             return;
         }
-        if (ui->lineEdit->text().isEmpty())
+        if (getNeedle().isEmpty())
             found = true;
 
         if (!found)
