@@ -1,7 +1,7 @@
 /************************************************************************
 **
 **
-**  Copyright (C) 2015-2019 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2024 Kevin B. Hendricks, Stratford Ontario Canada
 **  Copyright (C) 2012-2013 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012-2013 Dave Heiland
 **
@@ -34,6 +34,8 @@
 
 class QString;
 class QWebEngineView;
+class QTimer;
+class QWidget;
 
 class SelectFiles : public QDialog
 {
@@ -71,11 +73,11 @@ private slots:
     void PreviewLoadComplete(bool);
     void IncreaseThumbnailSize();
     void DecreaseThumbnailSize();
-
     void ReloadPreview();
-
     void SelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+
     void SelectDefaultImage();
+    void SetPreviewImage();
 
     /**
      * Filters the list of displayed images
@@ -92,8 +94,6 @@ private:
     void ReadSettings();
     void connectSignalsSlots();
 
-    void SetPreviewImage();
-
     QStringList m_MediaList;
     QStringList m_MediaKind;
     QString     m_MediaBase;
@@ -114,7 +114,7 @@ private:
     QListWidgetItem *m_ImageItem;
     QListWidgetItem *m_VideoItem;
     QListWidgetItem *m_AudioItem;
-
+    QTimer * m_ImageChangedTimer;
     QWebEngineView *m_WebView;
 
     Ui::SelectFiles ui;
