@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019  Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2019-2024  Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2019  Doug Massay
 **
 **  This file is part of PageEdit.
@@ -57,11 +57,7 @@ QString UIDictionary::GetDictionaryPath()
 
     // finally look inside the installed Qt directories
 #ifndef Q_OS_MAC
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    dict_path = QLibraryInfo::location(QLibraryInfo::DataPath) + "/qtwebengine_dictionaries";
-#else
     dict_path = QLibraryInfo::path(QLibraryInfo::DataPath) + "/qtwebengine_dictionaries";
-#endif
 #else
     dict_path = QCoreApplication::applicationDirPath() + 
       "/../Frameworks/QtWebEngineCore.framework/Resources/qtwebengine_dictionaries";
