@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019  Kevin B. Hendricks, Stratford, Ontario Canada 
+**  Copyright (C) 2019-2024  Kevin B. Hendricks, Stratford, Ontario Canada 
 **  Copyright (C) 2011  John Schember <john@nachtimwald.com>
 **
 **  This file is part of PageEdit.
@@ -43,12 +43,7 @@ QStringList UILanguage::GetPossibleTranslationPaths()
     possible_qm_locations.append(pageedit_share_root + "/translations/");
 #endif
     
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    possible_qm_locations.append(QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-#else
     possible_qm_locations.append(QLibraryInfo::path(QLibraryInfo::TranslationsPath));
-#endif
-    
 
 #ifdef Q_OS_MAC
     possible_qm_locations.append(QCoreApplication::applicationDirPath() + "/../translations");
