@@ -24,7 +24,7 @@
 #ifndef UILANGUAGE_H
 #define UILANGUAGE_H
 
-class QStringList;
+#include <QStringList>
 
 class UILanguage
 {
